@@ -137,6 +137,9 @@ addBracket <- function(top, bottom=NULL, idx=NULL, label=NULL, label.cex=0.75, t
   
   # get plotting details from aqp environment
   lsp <- get('last_spc_plot', envir=aqp.env)
+  depth.offset <- lsp$y.offset
+  sf <- lsp$scaling.factor
+  w <- lsp$width
   
   # get number of brackets ~ number bracket top boundaries
   n <- length(top)
@@ -147,10 +150,11 @@ addBracket <- function(top, bottom=NULL, idx=NULL, label=NULL, label.cex=0.75, t
   else
     plot.order <- idx
   
-  ## TODO: integrate these
-  y.offset <- lsp$y.offset
-  scaling.factor <- lsp$scaling.factor
-  w <- lsp$width
+  
+  # determine horizon depths in current setting
+  # depth_prime = (depth * scaling factor) + y.offset
+  top <- (top * sf) + depth.offset
+  bottom <- (bottom * sf) + depth.offset
   
 	# normal case: both top and bottom defined
 	if(!missing(top) & !missing(bottom)) {
@@ -211,11 +215,10 @@ hzDistinctnessCodeToOffset <- function(x, codes=c('A','C','G','D'), offset=c(0.5
 }
 
 # TODO: behavior not defined for horizons with an indefinate lower boundary
-# TODO: save important elements of geometry from last plot to aqp.env
 # TODO: move some of the processing outside of the main loop: column names, etc.
 
 ## basic function
-plotSPC <- function(x, color='soil_color', width=0.2, name=NULL, label=idname(x), alt.label=NULL, alt.label.col='black', cex.names=0.5, cex.depth.axis=cex.names, cex.id=cex.names+(0.2*cex.names), print.id=TRUE, id.style='auto', plot.order=1:length(x), add=FALSE, scaling.factor=1, y.offset=0, x.idx.offset=0, n=length(x), max.depth=max(x), n.depth.ticks=5, shrink=FALSE, shrink.cutoff=3, abbr=FALSE, abbr.cutoff=5, divide.hz=TRUE, hz.distinctness.offset=NULL, hz.distinctness.offset.col='black', hz.distinctness.offset.lty=2, axis.line.offset=-2.5, plot.depth.axis=TRUE, density=NULL, col.label=color, col.palette = rev(brewer.pal(10, 'Spectral')), col.legend.cex=1, lwd=1, lty=1, default.color=grey(0.95), ...) {
+plotSPC <- function(x, color='soil_color', width=0.2, name=NULL, label=idname(x), alt.label=NULL, alt.label.col='black', cex.names=0.5, cex.depth.axis=cex.names, cex.id=cex.names+(0.2*cex.names), print.id=TRUE, id.style='auto', plot.order=1:length(x), add=FALSE, scaling.factor=1, y.offset=0, x.idx.offset=0, n=length(x), max.depth=ifelse(is.infinite(max(x)), 200, max(x)), n.depth.ticks=5, shrink=FALSE, shrink.cutoff=3, abbr=FALSE, abbr.cutoff=5, divide.hz=TRUE, hz.distinctness.offset=NULL, hz.distinctness.offset.col='black', hz.distinctness.offset.lty=2, axis.line.offset=-2.5, plot.depth.axis=TRUE, density=NULL, col.label=color, col.palette = rev(brewer.pal(10, 'Spectral')), col.legend.cex=1, lwd=1, lty=1, default.color=grey(0.95), ...) {
   
   # save arguments to aqp env
   lsp <- list('width'=width, 'plot.order'=plot.order, 'y.offset'=y.offset, 'scaling.factor'=scaling.factor)
