@@ -16,7 +16,7 @@
 ## TODO:
 ## 1. allow iteration over groups for plotting multiple horizons
 ## 2. consider embedding into lattice panels
-## 3. consider integration with soiltexture package
+## 3. consider integration with soiltexture package (see GH issues)
 
 # helper function
 .get.ssc.low.rv.high <- function(ssc, p, delta) {
@@ -25,7 +25,7 @@
     stop('delta values smaller than 1 may result in memory overflow', call.=FALSE)
   
   # compute _univariate_ low - rv - high by variable
-  ssc.stats <- apply(ssc, 2, quantile, probs=p)
+  ssc.stats <- apply(ssc, 2, Hmisc::hdquantile, probs=p, na.rm=TRUE)
   
   # re-order for plotting
   sand.stats <- sort(ssc.stats[, 1])
@@ -38,8 +38,8 @@
   clay.seq <- round(seq(from=clay.stats[1], to=clay.stats[3], by=delta))
   g <- expand.grid(sand=sand.seq, silt=silt.seq, clay=clay.seq)
   
-  # subset to only include those sand, silt, clay values that sum to 100%
-  real.textures <- which(apply(g, 1, sum) - 100 == 0)
+  # subset to only include those sand, silt, clay values that sum to 100% (0.01% tolerance)
+  real.textures <- which(abs(apply(g, 1, sum) - 100) < 0.01 )
   g <- g[real.textures, ]
   
   # plot low and high values with no symbol, so that we can access the {x,y} screen coordinates
@@ -56,37 +56,46 @@
 # compute and plot "low"--"representative value"--"high" soil textures based on:
 # ssc: data.frame/matrix of [sand, silt, clay]
 # p: requested percentiles
-texture.triangle.low.rv.high <- function(ssc, p=c(0.05, 0.5, 0.95), delta=1, pop.rv.col='red', range.col='RoyalBlue', range.alpha=75, sim=FALSE, sim.n=1000, sim.rv.col='yellow', sim.col=grey(0.95), sim.alpha=150, legend.cex=0.75, ...) {
+textureTriangleSummary <- function(ssc, p=c(0.05, 0.5, 0.95), delta=1, texture.names=FALSE, pop.rv.col='red', range.col='RoyalBlue', range.alpha=75, sim=FALSE, sim.n=1000, sim.rv.col='yellow', sim.col=grey(0.95), sim.alpha=150, legend.cex=0.75, ...) {
 	
 	# setup colors
 	range.col <- rgb(t(col2rgb(range.col)), maxColorValue=255, alpha=range.alpha)
   sim.col <- rgb(t(col2rgb(sim.col)), maxColorValue=255, alpha=sim.alpha)
   
 	# setup legend elements
-	low.high.range.text <- paste0('Low-High Range (', paste(p[c(1,3)], collapse='-'), ')')
-	legend.text <- c('Population RV', low.high.range.text)
+  rv.text <- paste0('Sample RV (', paste(p[c(2)], collapse='-'), ')')
+  low.high.range.text <- paste0('Low-High Range (', paste(p[c(1,3)], collapse='-'), ')')
+	legend.text <- c(rv.text, low.high.range.text)
 	legend.cols <- c('black', 'black')
 	legend.bg <- c(pop.rv.col, range.col)
 	legend.pch <- c(22, 22)
   
 	# setup plot, without symbols at textures
-  soil.texture(ssc, show.names=FALSE, axis.labels=c('Sand', 'Silt', 'Clay'), show.grid=TRUE, pch=NA)
+  soil.texture(ssc, show.names=texture.names, axis.labels=c('Sand', 'Silt', 'Clay'), show.grid=TRUE, pch=NA)
 	
   # optionally simulate data from a composition of normally distributed data
   # using means, and var-cov matrix from original data
   if(sim) {
     if(!requireNamespace('compositions'))
       stop('pleast install the `compositions` package.', call.=FALSE)
+    
     # compute RV / range polygon for normally dist data
     # convert to compositional class, note range is now [0,1]
     ssc.acomp <- compositions::acomp(ssc)
+    
     # simulate normally-distributed composition based on data
-    ssc.sim <- compositions::rnorm.acomp(n=sim.n, mean=compositions::meanCol(ssc.acomp), var=cov(ssc.acomp))
-    # get range, and rv after converting back to [0,100] interval
+    # Note: it is critical that the mean and variance are estimated using functions from the compositions namespace
+    # BUG in calling var.acomp without loading compositions via library(): must specify default arguments
+    ssc.sim <- compositions::rnorm.acomp(n=sim.n, mean=compositions::meanCol(ssc.acomp), var=compositions::var(ssc.acomp, robust = FALSE, method='pearson'))
+    
+    # get bounding polygon and rv after converting back to [0,100] interval
     res.sim <- .get.ssc.low.rv.high(as.data.frame(unclass(ssc.sim) * 100),  p=p, delta=delta)
     
     # add polgon defining range of normally dist data
     polygon(res.sim$range$x, res.sim$range$y, col=sim.col, lty=2, lwd=2)
+    
+    # testing: add simulated points
+    # triax.points(as.data.frame(unclass(ssc.sim) * 100), col=1, cex=0.5)
   }
 	
   # compute RV / range polygon for data
@@ -105,7 +114,7 @@ texture.triangle.low.rv.high <- function(ssc, p=c(0.05, 0.5, 0.95), delta=1, pop
   
   # optionally add legend elements for simulation
   if(sim) {
-    legend.text <- c(legend.text, 'Simulated RV', paste0(sim.n, ' Simulations (normal composition)'))
+    legend.text <- c(legend.text, 'Simulated RV', paste0('Sim. Range (n=', sim.n, ', normal composition)'))
     legend.bg <- c(legend.bg, sim.rv.col, sim.col)
     legend.cols <- c(legend.cols, 'black', 'black')
     legend.pch <- c(legend.pch, 22, NA)
@@ -120,3 +129,10 @@ texture.triangle.low.rv.high <- function(ssc, p=c(0.05, 0.5, 0.95), delta=1, pop
 	
 
 }
+
+# for backwards compatibility
+texture.triangle.low.rv.high <- function(...) {
+  .Deprecated('textureTriangleSummary')
+  textureTriangleSummary(...)
+}
+
